@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 # Copyright Splunk Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,16 +15,12 @@
 
 import os
 import os.path
-import sys
 from argparse import REMAINDER, ArgumentParser
 from logging import getLogger
-from os import environ, execl, getcwd
-from shutil import which
-from typing import List, Union
 
 from opentelemetry.instrumentation.auto_instrumentation import run as otel_run
 
-from splunk_otel.version import format_version_info
+from splunk_otel.version import _format_version_info
 
 logger = getLogger(__file__)
 
@@ -65,14 +59,14 @@ ap.add_argument(
 def run() -> None:
     args = ap.parse_args()
     if args.version:
-        print(format_version_info())
+        print(_format_version_info())
         return
 
     if args.token:
         os.environ["SPLUNK_ACCESS_TOKEN"] = args.token
 
     if args.service_name:
-        os.environ["SPLUNK_SERVICE_NAME"] = args.service_name
+        os.environ["OTEL_SERVICE_NAME"] = args.service_name
 
     if not args.command:
         ap.error(ap.format_help())
@@ -82,3 +76,13 @@ def run() -> None:
     except TypeError:
         logger.error("failed to execute program: %s", " ".join(args.command))
         raise
+
+
+def run_deprecated() -> None:
+    logger.warning(
+        (
+            "splk-py-trace is deprecated and will be removed in a future version. "
+            "Please use `splunk-py-trace` instead."
+        )
+    )
+    run()
