@@ -14,21 +14,9 @@
 
 from os import environ
 
-_OTEL_SPAN_LINK_COUNT_LIMIT = "OTEL_SPAN_LINK_COUNT_LIMIT"
-_OTEL_SPAN_LINK_COUNT_LIMIT_DEFAULT = "1000"
-
-_OTEL_SPAN_ATTRIBUTE_COUNT_LIMIT = "OTEL_SPAN_ATTRIBUTE_COUNT_LIMIT"
-_OTEL_SPAN_EVENT_COUNT_LIMIT = "OTEL_SPAN_EVENT_COUNT_LIMIT"
-
-_UNLIMITED = "999999"
+_OTEL_PYTHON_LOG_CORRELATION = "OTEL_PYTHON_LOG_CORRELATION"
 
 
 def _set_otel_defaults() -> None:
-    if _OTEL_SPAN_LINK_COUNT_LIMIT not in environ:
-        environ[_OTEL_SPAN_LINK_COUNT_LIMIT] = _OTEL_SPAN_LINK_COUNT_LIMIT_DEFAULT
-
-    if _OTEL_SPAN_ATTRIBUTE_COUNT_LIMIT not in environ:
-        environ[_OTEL_SPAN_ATTRIBUTE_COUNT_LIMIT] = _UNLIMITED
-
-    if _OTEL_SPAN_EVENT_COUNT_LIMIT not in environ:
-        environ[_OTEL_SPAN_EVENT_COUNT_LIMIT] = _UNLIMITED
+    if _OTEL_PYTHON_LOG_CORRELATION not in environ:
+        environ[_OTEL_PYTHON_LOG_CORRELATION] = "true"
