@@ -12,7 +12,5 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-SPLUNK_ACCESS_TOKEN = "SPLUNK_ACCESS_TOKEN"
-SPLUNK_MAX_ATTR_LENGTH = "SPLUNK_MAX_ATTR_LENGTH"
-SPLUNK_TRACE_RESPONSE_HEADER_ENABLED = "SPLUNK_TRACE_RESPONSE_HEADER_ENABLED"
-SPLUNK_SERVICE_NAME = "SPLUNK_SERVICE_NAME"
+_SPLUNK_ACCESS_TOKEN = "SPLUNK_ACCESS_TOKEN"
+_SPLUNK_TRACE_RESPONSE_HEADER_ENABLED = "SPLUNK_TRACE_RESPONSE_HEADER_ENABLED"
